# TE-SYSTEMS GmbH
# Script date: May 2024

# The following actions are performed by this script:
# 	- Export of an backup of the anynode configuration

# In order to use the script, some variables must be adjusted.
#	- The path to the REST API PowerShell-Module must be set.
#		By default, the Powershell-Modul is in the folder directly above the one in which this script is located.
#	- The address of  anynode must be set.
#		By default the address is set to localhost.

#  	--- Config backup export ---
#   - The path the backup should be saved at must be defined.
# 	- The data the backup should include can be adjusted.
# 		For all available parameters view the REST API documentation.

# Please check all existing parameters before starting the script.

# Set execution environment
Set-ExecutionPolicy -ExecutionPolicy Unrestricted -Scope Process


#---- Variables ----
# The path to the REST API PowerShell-Module must be specified. In this case. 
# 	In this case it is in the folder above the one where this script is located.
Import-Module "./../anynode_rest_api_powershell.psm1"

# Define anynode's Address and Port.
$AnynodeAddress='127.0.0.1'
$AnynodePort=443

# Define if the backup data should be encrypted and if so, define a password.
$EncryptBackupData=$false
$BackupPassword=''

# The Path the backup-file should be saved at.
$BackupPath='EXPORT PATH'

# Define which components will be included in the backup.
$BackupParameter=@( 
		"ANYNODE_CONFIG",
        "MEDIA_FILES",
        "HTTP_SERVER_FILES",
        "FRONTEND_CONFIG",
        "MONITOR_CONFIG",
        "CALL_HISTORY",
        "EVENT_LOG"
    )

# If you have not established a secure connection (HTTPS) to anynode,
# you can use HTTP instead.
# This is not recommended, since your data will NOT be encrypted!
# To activate it anyway, uncomment the following line:
# Disable-CertificateCheck


# Authentication
$Cred=Get-Credential

# ----------- Start of script -----------
try {
	# Creating the anynode config backup.
	if($EncryptBackupData -eq $true) {
		# Encrypting the exported anynode config backup using the defined password.
		Create-anynodeConfigBackup -Address $AnynodeAddress -Port $AnynodePort -Credential $Cred -IncludedData $BackupParameter -Filename $BackupPath -Encryptdata $EncryptBackupData -ZipPassword $BackupPassword
	} else {
		Create-anynodeConfigBackup -Address $AnynodeAddress -Port $AnynodePort -Credential $Cred -IncludedData $BackupParameter -Filename $BackupPath -Encryptdata $EncryptBackupData
	}	
} catch {
	$_.Exception.Message
	pause
	return
}